Class: Decidim::CollaborativeTexts::Admin::PublishDocument

Inherits:
Decidim::Command
  • Object
show all
Defined in:
app/commands/decidim/collaborative_texts/admin/publish_document.rb

Overview

This command is executed when the user publishes an existing collaborative text document.

Instance Method Summary collapse

Constructor Details

#initialize(document, current_user) ⇒ PublishDocument

Public: Initializes the command.

document - Decidim::CollaborativeTexts::Document current_user - the user performing the action



13
14
15
16
# File 'app/commands/decidim/collaborative_texts/admin/publish_document.rb', line 13

def initialize(document, current_user)
  @document = document
  @current_user = current_user
end

Instance Method Details

#callObject

Executes the command. Broadcasts these events:

  • :ok when everything is valid.

  • :invalid if the form was not valid and we could not proceed.

Returns nothing.



24
25
26
27
28
29
30
31
32
# File 'app/commands/decidim/collaborative_texts/admin/publish_document.rb', line 24

def call
  return broadcast(:invalid) if document.published?

  transaction do
    publish_document
  end

  broadcast(:ok, document)
end