Class: Decidim::CollaborativeTexts::AdminLog::VersionPresenter

Inherits:
Log::BasePresenter
  • Object
show all
Defined in:
app/presenters/decidim/collaborative_texts/admin_log/version_presenter.rb

Overview

This class holds the logic to present a ‘Decidim::CollaborativeTexts::Version` for the `AdminLog` log. Note that this is only used in updates, creation is handled by the document creation.