Class: Decidim::CollaborativeTexts::ApplicationController
- Inherits:
-
Decidim::Components::BaseController
- Object
- Decidim::Components::BaseController
- Decidim::CollaborativeTexts::ApplicationController
- Defined in:
- app/controllers/decidim/collaborative_texts/application_controller.rb
Overview
This controller is the abstract class from which all other controllers of this engine inherit.
Note that it inherits from ‘Decidim::Components::Basecontroller`, which override its layout and provide all kinds of useful methods.