Class: Decidim::CollaborativeTexts::Suggestion

Inherits:
ApplicationRecord
  • Object
show all
Includes:
Authorable, Traceable
Defined in:
app/models/decidim/collaborative_texts/suggestion.rb

Overview

The data store for a document in the Decidim::CollaborativeTexts component. It stores a title, description and any other useful information to render a custom document.

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.log_presenter_class_for(_log) ⇒ Object



20
21
22
# File 'app/models/decidim/collaborative_texts/suggestion.rb', line 20

def self.log_presenter_class_for(_log)
  Decidim::CollaborativeTexts::AdminLog::SuggestionPresenter
end

Instance Method Details

#presenterObject



24
25
26
# File 'app/models/decidim/collaborative_texts/suggestion.rb', line 24

def presenter
  @presenter ||= Decidim::CollaborativeTexts::SuggestionPresenter.new(self)
end