Class: Decidim::CollaborativeTexts::DocumentCell
- Inherits:
-
ViewModel
- Object
- ViewModel
- Decidim::CollaborativeTexts::DocumentCell
- Includes:
- Cell::ViewModel::Partial
- Defined in:
- app/cells/decidim/collaborative_texts/document_cell.rb
Overview
This cell renders the document card for an instance of a Document the default size is the List Card (:l)
Instance Method Summary collapse
Instance Method Details
#show ⇒ Object
12 13 14 |
# File 'app/cells/decidim/collaborative_texts/document_cell.rb', line 12 def show cell card_size, model, end |